@@ -80,6 +80,10 @@ module IAIConvert
     end
   end
 
+  function convert_to_jl_set(o::PyObject)
+    Set(collect(o))
+  end
+
 
   convert_to_jl(o) = o
   function convert_to_jl(o::PyObject)
@@ -89,6 +93,8 @@ module IAIConvert
       convert_to_jl_dataframe(o)
     elseif pyisinstance(o, np.ndarray)
       convert_to_jl_ndarray(o)
+    elseif pyisinstance(o, py"set")
+      convert_to_jl_set(o)
     else
       o
     end
@@ -221,3 +227,12 @@ if !isdefined(IAI, :get_machine_id_convert)
     end
   end
 end
+
+if isdefined(IAI, :IAILicensing) &&
+   isdefined(IAI.IAILicensing, :acquire_license_all_procs)
+  @eval IAI begin
+    function acquire_license_all_procs_convert(args...; kwargs...)
+      IAILicensing.acquire_license_all_procs(args...; kwargs...)
+    end
+  end
+end
