@@ -4,7 +4,11 @@ from .iaibase import (Learner, ClassificationLearner, RegressionLearner,
 
 
 class RandomForestLearner(Learner):
-    """Abstract type encompassing all random forest learners."""
+    """Abstract type encompassing all random forest learners.
+
+    Julia Equivalent:
+    `IAI.RandomForestLearner <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.RandomForestLearner>`
+    """
     pass
 
 
@@ -12,7 +16,7 @@ class RandomForestClassifier(RandomForestLearner, ClassificationLearner):
     """Learner for training random forests for classification problems.
 
     Julia Equivalent:
-    `IAI.RandomForestClassifier <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.RandomForestClassifier>`
+    `IAI.RandomForestClassifier <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.RandomForestClassifier>`
 
     Examples
     --------
@@ -37,7 +41,7 @@ class RandomForestRegressor(RandomForestLearner, RegressionLearner):
     """Learner for training random forests for regression problems.
 
     Julia Equivalent:
-    `IAI.RandomForestRegressor <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.RandomForestRegressor>`
+    `IAI.RandomForestRegressor <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.RandomForestRegressor>`
 
     Examples
     --------
@@ -62,7 +66,7 @@ class RandomForestSurvivalLearner(RandomForestLearner, SurvivalLearner):
     """Learner for training random forests for survival problems.
 
     Julia Equivalent:
-    `IAI.RandomForestSurvivalLearner <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.RandomForestSurvivalLearner>`
+    `IAI.RandomForestSurvivalLearner <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.RandomForestSurvivalLearner>`
 
     Examples
     --------
@@ -84,13 +88,17 @@ class RandomForestSurvivalLearner(RandomForestLearner, SurvivalLearner):
 
 
 class XGBoostLearner(Learner):
-    """Abstract type encompassing all XGBoost learners."""
+    """Abstract type encompassing all XGBoost learners.
+
+    Julia Equivalent:
+    `IAI.XGBoostLearner <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.XGBoostLearner>`
+    """
 
     def write_booster(self, filename, **kwargs):
         """Write the internal booster saved in the learner to `filename`.
 
         Julia Equivalent:
-        `IAI.write_booster <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.write_booster>`
+        `IAI.write_booster <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.write_booster>`
 
         Examples
         --------
@@ -107,7 +115,7 @@ class XGBoostLearner(Learner):
         """Calculate SHAP values for all points in the features `X` using `lnr`.
 
         Julia Equivalent:
-        `IAI.predict_shap <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.predict_shap>`
+        `IAI.predict_shap <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.predict_shap>`
 
         Examples
         --------
@@ -125,7 +133,7 @@ class XGBoostClassifier(XGBoostLearner, ClassificationLearner):
     """Learner for training XGBoost models for classification problems.
 
     Julia Equivalent:
-    `IAI.XGBoostClassifier <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.XGBoostClassifier>`
+    `IAI.XGBoostClassifier <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.XGBoostClassifier>`
 
     Examples
     --------
@@ -150,7 +158,7 @@ class XGBoostRegressor(XGBoostLearner, RegressionLearner):
     """Learner for training XGBoost models for regression problems.
 
     Julia Equivalent:
-    `IAI.XGBoostRegressor <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.XGBoostRegressor>`
+    `IAI.XGBoostRegressor <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.XGBoostRegressor>`
 
     Examples
     --------
@@ -175,7 +183,7 @@ class XGBoostSurvivalLearner(XGBoostLearner, SurvivalLearner):
     """Learner for training XGBoost models for survival problems.
 
     Julia Equivalent:
-    `IAI.XGBoostSurvivalLearner <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.XGBoostSurvivalLearner>`
+    `IAI.XGBoostSurvivalLearner <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.XGBoostSurvivalLearner>`
 
     Examples
     --------
@@ -197,13 +205,17 @@ class XGBoostSurvivalLearner(XGBoostLearner, SurvivalLearner):
 
 
 class GLMNetLearner(Learner):
-    """Abstract type encompassing all GLMNet learners."""
+    """Abstract type encompassing all GLMNet learners.
+
+    Julia Equivalent:
+    `IAI.GLMNetLearner <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.GLMNetLearner>`
+    """
 
     def get_num_fits(self):
         """Return the number of fits along the path in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_fits <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.get_num_fits>`
+        `IAI.get_num_fits <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.get_num_fits-Tuple%7BGLMNetCVLearner%7D>`
 
         Examples
         --------
@@ -220,7 +232,7 @@ class GLMNetLearner(Learner):
         """Return the constant term in the prediction in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prediction_constant <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.get_prediction_constant>`
+        `IAI.get_prediction_constant <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.get_prediction_constant-Tuple%7BGLMNetCVLearner%7D>`
 
         Examples
         --------
@@ -247,7 +259,7 @@ class GLMNetLearner(Learner):
         prediction in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prediction_weights <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.get_prediction_weights>`
+        `IAI.get_prediction_weights <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.get_prediction_weights-Tuple%7BGLMNetCVLearner%7D>`
 
         Examples
         --------
@@ -272,8 +284,59 @@ class GLMNetLearner(Learner):
 
 class GLMNetCVLearner(GLMNetLearner):
     """Abstract type encompassing all GLMNet learners using
-    cross-validation."""
-    pass
+    cross-validation.
+
+    Julia Equivalent:
+    `IAI.GLMNetCVLearner <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.GLMNetCVLearner>`
+    """
+    def predict(self, *args, **kwargs):
+        """Return the prediction made by the learner for each point in the data
+        `X`.
+
+        Julia Equivalent:
+        `IAI.predict <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.predict-Tuple%7BGLMNetCVLearner%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
+
+        Examples
+        --------
+        Return the prediction made by the best fit on the path in the learner.
+
+        >>> lnr.predict(X)
+
+        Return the prediction made by the fit at `fit_index` on the path in the
+        learner.
+
+        >>> lnr.predict(X, fit_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "predict")
+        return super().predict(*args, **kwargs)
+
+    def score(self, *args, **kwargs):
+        """Calculate the score for the learner on data `X` and `y`
+
+        Julia Equivalent:
+        `IAI.score <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.score-Tuple%7BGLMNetCVLearner%7D>`
+
+        Examples
+        --------
+        Calculate the score for by the best fit on the path in the learner.
+
+        >>> lnr.score(X, *y, **kwargs)
+
+        Calculate the score for by the fit at `fit_index` on the path in the
+        learner.
+
+        >>> lnr.score(X, *y, fit_index=fit_index, **kwargs)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "score")
+        return _IAI.score_convert(self._jl_obj, *args, **kwargs)
 
 
 class GLMNetCVRegressor(GLMNetCVLearner, RegressionLearner):
@@ -281,7 +344,7 @@ class GLMNetCVRegressor(GLMNetCVLearner, RegressionLearner):
     cross-validation.
 
     Julia Equivalent:
-    `IAI.GLMNetCVRegressor <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.GLMNetCVRegressor>`
+    `IAI.GLMNetCVRegressor <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.GLMNetCVRegressor>`
 
     Examples
     --------
@@ -307,7 +370,7 @@ class GLMNetCVClassifier(GLMNetCVLearner, ClassificationLearner):
     cross-validation.
 
     Julia Equivalent:
-    `IAI.GLMNetCVClassifier <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.GLMNetCVClassifier>`
+    `IAI.GLMNetCVClassifier <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.GLMNetCVClassifier>`
 
     Examples
     --------
@@ -320,20 +383,71 @@ class GLMNetCVClassifier(GLMNetCVLearner, ClassificationLearner):
 
     Compatibility
     -------------
-    Requires IAI version 2.3 or higher.
+    Requires IAI version 3.0 or higher.
     """
     def __init__(self, *args, **kwargs):
-        _requires_iai_version("2.3.0", "GLMNetCVClassifier")
+        _requires_iai_version("3.0.0", "GLMNetCVClassifier")
         jl_obj = _IAI.GLMNetCVClassifier_convert(*args, **kwargs)
         super().__init__(jl_obj)
 
+    def predict_proba(self, *args, **kwargs):
+        """Return the probabilities of class membership predicted by the
+        learner for each point in the data `X`.
+
+        Julia Equivalent:
+        `IAI.predict_proba <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.predict_proba-Tuple%7BGLMNetCVClassifier%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
+
+        Examples
+        --------
+        Return the probabilities of class membership predicted by the best fit on the path in the learner.
+
+        >>> lnr.predict_proba(X)
+
+        Return the probabilities of class membership predicted by the fit at
+        `fit_index` on the path in the learner.
+
+        >>> lnr.predict_proba(X, fit_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "predict_proba")
+        return super().predict_proba(*args, **kwargs)
+
+    def ROCCurve(self, *args, **kwargs):
+        """Construct an
+        :meth:`interpretableai.iai.ROCCurve`
+        using the trained learner on the features `X` and labels `y`
+
+        Julia Equivalent:
+        `IAI.ROCCurve <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.ROCCurve-Tuple%7BGLMNetCVClassifier%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%2C%20AbstractVector%7D>`
+
+        Examples
+        --------
+        Construct an ROCCurve using by the best fit on the path in the learner.
+
+        >>> lnr.predict_proba(X)
+
+        Construct an ROCCurve using by the fit at `fit_index` on the path in
+        the learner.
+
+        >>> iai.ROCCurve(lnr, X, y, fit_index=fit_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "ROCCurve")
+        return super().ROCCurve(*args, **kwargs)
+
 
 class GLMNetCVSurvivalLearner(GLMNetCVLearner, SurvivalLearner):
     """Learner for training GLMNet models for survival problems with
     cross-validation.
 
     Julia Equivalent:
-    `IAI.GLMNetCVSurvivalLearner <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.GLMNetCVSurvivalLearner>`
+    `IAI.GLMNetCVSurvivalLearner <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.GLMNetCVSurvivalLearner>`
 
     Examples
     --------
@@ -358,7 +472,7 @@ class GLMNetCVSurvivalLearner(GLMNetCVLearner, SurvivalLearner):
         each point in the data `X`.
 
         Julia Equivalent:
-        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
+        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.predict_expected_survival_time-Tuple%7BGLMNetCVSurvivalLearner%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
 
         Examples
         --------
@@ -388,7 +502,7 @@ class GLMNetCVSurvivalLearner(GLMNetCVLearner, SurvivalLearner):
         survival time.
 
         Julia Equivalent:
-        `IAI.predict_hazard <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_hazard>`
+        `IAI.predict_hazard <https://docs.interpretable.ai/v3.1.0/Heuristics/reference/#IAI.predict_hazard-Tuple%7BGLMNetCVSurvivalLearner%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
 
         Examples
         --------
