@@ -10,7 +10,7 @@ def split_data(*args, **kwargs):
     `(X_train, y_train), (X_test, y_test)`, for a problem of type `task`.
 
     Julia Equivalent:
-    `IAI.split_data <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.split_data>`
+    `IAI.split_data <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.split_data>`
 
     Examples
     --------
@@ -23,7 +23,7 @@ def set_rich_output_param(*args, **kwargs):
     """Sets the global rich output parameter `key` to `value`.
 
     Julia Equivalent:
-    `IAI.set_rich_output_param! <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.set_rich_output_param!>`
+    `IAI.set_rich_output_param! <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.set_rich_output_param!>`
 
     Examples
     --------
@@ -36,7 +36,7 @@ def get_rich_output_params(*args, **kwargs):
     """Return the current global rich output parameter settings.
 
     Julia Equivalent:
-    `IAI.get_rich_output_params <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_rich_output_params>`
+    `IAI.get_rich_output_params <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_rich_output_params>`
 
     Examples
     --------
@@ -49,7 +49,7 @@ def delete_rich_output_param(*args, **kwargs):
     """Delete the global rich output parameter `key`.
 
     Julia Equivalent:
-    `IAI.delete_rich_output_param! <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.delete_rich_output_param!>`
+    `IAI.delete_rich_output_param! <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.delete_rich_output_param!>`
 
     Examples
     --------
@@ -62,7 +62,7 @@ def read_json(filename):
     """Read in a learner or grid saved in JSON format from `filename`.
 
     Julia Equivalent:
-    `IAI.read_json <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.read_json>`
+    `IAI.read_json <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.read_json>`
 
     Examples
     --------
@@ -70,7 +70,32 @@ def read_json(filename):
     """
 
     jl_obj = _IAI.read_json_convert(filename)
+    return _wrap_jl_learner(jl_obj)
 
+
+def resume_from_checkpoint(checkpoint_file):
+    """Resume training from the supplied `checkpoint_file`.
+
+    Julia Equivalent:
+    `IAI.resume_from_checkpoint <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.resume_from_checkpoint>`
+
+    Examples
+    --------
+    >>> iai.resume_from_checkpoint(checkpoint_file)
+
+    Compatibility
+    -------------
+    Requires IAI version 3.1 or higher.
+    """
+    _requires_iai_version("3.1.0", "resume_from_checkpoint")
+    out = _IAI.resume_from_checkpoint_convert(checkpoint_file)
+    if type(out) == tuple:
+        return _wrap_jl_learner(out[0]), out[1]
+    else:
+        return _wrap_jl_learner(out)
+
+
+def _wrap_jl_learner(jl_obj):
     if _Main.isa(jl_obj, _IAI.GridSearch):
         lnr = _get_learner_type(_IAI.get_learner(jl_obj))()
         grid = GridSearch(lnr)
@@ -87,7 +112,7 @@ def score(*args, **kwargs):
     `truths` for the problem type indicated by `task`.
 
     Julia Equivalent:
-    `IAI.score <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.score-Tuple{Union{AbstractString,%20Symbol},%20Vararg{Any,%20N}%20where%20N}>`
+    `IAI.score <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.score-Tuple%7BUnion%7BAbstractString%2C%20Symbol%7D%2C%20Vararg%7BAny%7D%7D>`
 
     Examples
     --------
@@ -101,8 +126,122 @@ def score(*args, **kwargs):
     return _IAI.score_convert(*args, **kwargs)
 
 
+class AbstractVisualization():
+    """Abstract type encompassing objects related to visualization.
+
+    Julia Equivalent:
+    `IAI.AbstractVisualization <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.AbstractVisualization>`
+    """
+    def __init__(self, jl_obj):
+        self._jl_obj = jl_obj
+
+    def __repr__(self):
+        return _IAI.string(self._jl_obj)
+
+    def _repr_html_(self):
+        return _IAI.to_html(self._jl_obj)
+
+    def write_html(self, filename, **kwargs):
+        """Write interactive browser visualization to `filename` as HTML.
+
+        Julia Equivalent:
+        `IAI.write_html <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_html-Tuple%7BAny%2C%20AbstractVisualization%7D>`
+
+        Examples
+        --------
+        >>> treeplot.write_html(filename, **kwargs)
+        """
+        return _IAI.write_html_convert(filename, self._jl_obj, **kwargs)
+
+    def show_in_browser(self, **kwargs):  # pragma: no cover
+        """Show interactive visualization in default browser.
+
+        Julia Equivalent:
+        `IAI.show_in_browser <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.show_in_browser-Tuple%7BAbstractVisualization%7D>`
+
+        Examples
+        --------
+        >>> treeplot.show_in_browser(**kwargs)
+        """
+        return _IAI.show_in_browser_convert(self._jl_obj, **kwargs)
+
+
+class Questionnaire(AbstractVisualization):
+    """Specifies an interactive questionnaire.
+
+    Julia Equivalent:
+    `IAI.Questionnaire <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.Questionnaire-Tuple%7BLearner%7D>`
+
+    Parameters
+    ----------
+
+    Refer to the
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v3.1.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    for available parameters.
+
+    Compatibility
+    -------------
+    Requires IAI version 1.1 or higher.
+    """
+    def __init__(self, lnr, **kwargs):
+        _requires_iai_version("1.1.0", "Questionnaire")
+
+        if isinstance(lnr, Learner):
+            _warnings.warn(
+                "'iai.Questionnaire(lnr)' is deprecated, use " +
+                "`lnr.Questionnaire(...)`",
+                FutureWarning
+            )
+            jl_obj = _IAI.Questionnaire_convert(lnr._jl_obj, **kwargs)
+        else:
+            jl_obj = _IAI.Questionnaire_convert(lnr, **kwargs)
+        super().__init__(jl_obj)
+
+
+class MultiQuestionnaire(AbstractVisualization):
+    """Specify an interactive questionnaire of multiple learners
+
+    Examples
+    --------
+    Constructs an interactive questionnaire using multiple learners from
+    specified questions. Refer to the
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v3.1.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    for more information.
+
+    Julia Equivalent:
+    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.MultiQuestionnaire-Tuple%7BPair%7D>`
+
+    >>> iai.MultiQuestionnaire(questions)
+
+    Compatibility
+    -------------
+    Requires IAI version 1.1 or higher.
+    """
+    def __init__(self, *args):
+        if len(args) > 0 and isinstance(args[0], GridSearch):
+            _requires_iai_version("2.0.0", "MultiQuestionnaire")
+            args = list(args)
+            grid = args.pop(0)
+
+            _warnings.warn(
+                "'iai.MultiQuestionnaire(grid, ...)' is deprecated, use " +
+                "`grid.MultiQuestionnaire(...)`",
+                FutureWarning
+            )
+
+            jl_obj = _IAI.MultiQuestionnaire_convert(grid._jl_obj, *args)
+        else:
+            _requires_iai_version("1.1.0", "MultiQuestionnaire")
+            jl_obj = _IAI.MultiQuestionnaire_convert(*args)
+        super().__init__(jl_obj)
+
+
 class Learner():
-    """Abstract type encompassing all learners"""
+    """Abstract type encompassing all learners.
+
+    Julia Equivalent:
+    `IAI.Learner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.Learner>`
+    """
     def __init__(self, jl_obj):
         self._jl_obj = jl_obj
 
@@ -168,7 +307,7 @@ class Learner():
         """Fit a model using the parameters in learner and the data `X` and `y`.
 
         Julia Equivalent:
-        `IAI.fit! <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit!>`
+        `IAI.fit! <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit%21-Tuple%7BLearner%7D>`
 
         Examples
         --------
@@ -177,7 +316,7 @@ class Learner():
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v3.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v3.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         _IAI.fit_convert(self._jl_obj, *args, **kwargs)
@@ -187,7 +326,7 @@ class Learner():
         """Write learner or grid to `filename` in JSON format.
 
         Julia Equivalent:
-        `IAI.write_json <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.write_json>`
+        `IAI.write_json <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_json>`
 
         Examples
         --------
@@ -202,7 +341,7 @@ class Learner():
         """Return the value of all learner parameters.
 
         Julia Equivalent:
-        `IAI.get_params <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_params>`
+        `IAI.get_params <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_params>`
 
         Examples
         --------
@@ -217,7 +356,7 @@ class Learner():
         """Set all supplied parameters on learner.
 
         Julia Equivalent:
-        `IAI.set_params! <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.set_params!>`
+        `IAI.set_params! <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.set_params!>`
 
         Examples
         --------
@@ -233,7 +372,7 @@ class Learner():
         """Return an unfitted copy of the learner with the same parameters.
 
         Julia Equivalent:
-        `IAI.clone <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.clone>`
+        `IAI.clone <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.clone>`
 
         Examples
         --------
@@ -246,42 +385,13 @@ class Learner():
         Learner.__init__(lnr, _IAI.clone(self._jl_obj))
         return lnr
 
-
-class SupervisedLearner(Learner):
-    """Abstract type encompassing all learners for supervised tasks"""
-
-    def predict(self, *args, **kwargs):
-        """Return the predictions made by the learner for each point in the
-        features `X`.
-
-        Julia Equivalent:
-        `IAI.predict <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict>`
-
-        Examples
-        --------
-        >>> lnr.predict(X)
-        """
-        return _IAI.predict_convert(self._jl_obj, *args, **kwargs)
-
-    def score(self, *args, **kwargs):
-        """Calculates the score for the learner on data `X` and `y`.
-
-        Julia Equivalent:
-        `IAI.score <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.score>`
-
-        Examples
-        --------
-        >>> lnr.score(X, *y, **kwargs)
-        """
-        return _IAI.score_convert(self._jl_obj, *args, **kwargs)
-
     def variable_importance(self, *args, **kwargs):
         """Generate a ranking of the variables in the learner according to
         their importance during training. The results are normalized so that
         they sum to one.
 
         Julia Equivalent:
-        `IAI.variable_importance <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.variable_importance>`
+        `IAI.variable_importance <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.variable_importance-Tuple%7BLearner%7D>`
 
         Examples
         --------
@@ -293,7 +403,7 @@ class SupervisedLearner(Learner):
         """Return a list of feature names used by the learner.
 
         Julia Equivalent:
-        `IAI.get_features_used <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_features_used>`
+        `IAI.get_features_used <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_features_used-Tuple%7BLearner%7D>`
 
         Examples
         --------
@@ -307,20 +417,61 @@ class SupervisedLearner(Learner):
         return _IAI.get_features_used_convert(self._jl_obj)
 
 
+class SupervisedLearner(Learner):
+    """Abstract type encompassing all learners for supervised tasks.
+
+    Julia Equivalent:
+    `IAI.SupervisedLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.SupervisedLearner>`
+    """
+
+    def predict(self, *args, **kwargs):
+        """Return the predictions made by the learner for each point in the
+        features `X`.
+
+        Julia Equivalent:
+        `IAI.predict <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict-Tuple%7BSupervisedLearner%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
+
+        Examples
+        --------
+        >>> lnr.predict(X)
+        """
+        return _IAI.predict_convert(self._jl_obj, *args, **kwargs)
+
+    def score(self, *args, **kwargs):
+        """Calculates the score for the learner on data `X` and `y`.
+
+        Julia Equivalent:
+        `IAI.score <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.score-Tuple%7BSupervisedLearner%7D>`
+
+        Examples
+        --------
+        >>> lnr.score(X, *y, **kwargs)
+        """
+        return _IAI.score_convert(self._jl_obj, *args, **kwargs)
+
+
 class UnsupervisedLearner(Learner):
-    """Abstract type encompassing all learners for unsupervised tasks"""
+    """Abstract type encompassing all learners for unsupervised tasks.
+
+    Julia Equivalent:
+    `IAI.UnsupervisedLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.UnsupervisedLearner>`
+    """
     pass
 
 
 class ClassificationLearner(SupervisedLearner):
-    """Abstract type encompassing all learners for classification tasks"""
+    """Abstract type encompassing all learners for classification tasks.
+
+    Julia Equivalent:
+    `IAI.ClassificationLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.ClassificationLearner>`
+    """
 
     def predict_proba(self, *args, **kwargs):
         """Return the probabilities of class membership predicted by the
         learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_proba <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_proba>`
+        `IAI.predict_proba <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_proba-Tuple%7BLearner%7BIAIBase.ClassificationTask%7D%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
 
         Examples
         --------
@@ -328,16 +479,58 @@ class ClassificationLearner(SupervisedLearner):
         """
         return _IAI.predict_proba_convert(self._jl_obj, *args, **kwargs)
 
+    def ROCCurve(self, *args, **kwargs):
+        """Construct an
+        :meth:`interpretableai.iai.ROCCurve`
+        using the trained learner on the features `X` and labels `y`
+
+        Julia Equivalent:
+        `IAI.ROCCurve <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.ROCCurve-Tuple%7BLearner%7BIAIBase.ClassificationTask%7D%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%2C%20AbstractVector%7D>`
+
+        Examples
+        --------
+        >>> lnr.ROCCurve(X, y)
+        """
+        return ROCCurve(self._jl_obj, *args, **kwargs)
+
 
 class RegressionLearner(SupervisedLearner):
-    """Abstract type encompassing all learners for regression tasks"""
+    """Abstract type encompassing all learners for regression tasks.
+
+    Julia Equivalent:
+    `IAI.RegressionLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.RegressionLearner>`
+    """
     pass
 
 
 class SurvivalLearner(SupervisedLearner):
-    """Abstract type encompassing all learners for survival tasks"""
+    """Abstract type encompassing all learners for survival tasks.
+
+    Julia Equivalent:
+    `IAI.SurvivalLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.SurvivalLearner>`
+    """
 
     def predict(self, *args, **kwargs):
+        """
+        Return the predictions made by the learner for each point in the
+        features `X` (see
+        :meth:`interpretableai.iai.SupervisedLearner.predict`)..
+
+        Julia Equivalent:
+        `IAI.predict <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict-Tuple%7BLearner%7BIAIBase.SurvivalTask%7D%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
+
+        Examples
+        --------
+        Return the :meth:`interpretableai.iai.SurvivalCurve` predicted by the
+        trained learner for each point in the data.
+
+        >>> lnr.predict(X)
+
+        Return the probability that death occurs at or before time `t` as
+        predicted by the trained learner for each point.
+
+        >>> lnr.predict(X, t=t)
+        """
         out = _IAI.predict_convert(self._jl_obj, *args, **kwargs)
         if len(out) > 0 and out[0].__class__.__name__ == 'jlwrap':
             return [SurvivalCurve(jl_curve) for jl_curve in out]
@@ -349,7 +542,7 @@ class SurvivalLearner(SupervisedLearner):
         each point in the data `X`.
 
         Julia Equivalent:
-        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
+        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_expected_survival_time-Tuple%7BLearner%7BIAIBase.SurvivalTask%7D%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
 
         Examples
         --------
@@ -371,7 +564,7 @@ class SurvivalLearner(SupervisedLearner):
         survival time.
 
         Julia Equivalent:
-        `IAI.predict_hazard <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_hazard>`
+        `IAI.predict_hazard <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_hazard-Tuple%7BLearner%7BIAIBase.SurvivalTask%7D%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
 
         Examples
         --------
@@ -386,14 +579,18 @@ class SurvivalLearner(SupervisedLearner):
 
 
 class PrescriptionLearner(SupervisedLearner):
-    """Abstract type encompassing all learners for prescription tasks"""
+    """Abstract type encompassing all learners for prescription tasks.
+
+    Julia Equivalent:
+    `IAI.PrescriptionLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.PrescriptionLearner>`
+    """
 
     def predict_outcomes(self, *args, **kwargs):
         """Return the the predicted outcome for each treatment made by the
         learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_outcomes <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_outcomes-Tuple%7BLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D>`
+        `IAI.predict_outcomes <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_outcomes-Tuple%7BPrescriptionLearner%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
 
         Examples
         --------
@@ -403,14 +600,18 @@ class PrescriptionLearner(SupervisedLearner):
 
 
 class PolicyLearner(SupervisedLearner):
-    """Abstract type encompassing all learners for policy tasks"""
+    """Abstract type encompassing all learners for policy tasks.
+
+    Julia Equivalent:
+    `IAI.PolicyLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.PolicyLearner>`
+    """
 
     def predict_outcomes(self, *args, **kwargs):
         """Return the outcome from `rewards` for each point in the features `X`
         under the prescriptions made by the learner.
 
         Julia Equivalent:
-        `IAI.predict_outcomes <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_outcomes-Union%7BTuple%7BO%7D%2C%2520Tuple%7BLearner%7BIAIBase.PolicyTask%7BO%7D%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D%7D%2520where%2520O>`
+        `IAI.predict_outcomes <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_outcomes-Tuple%7BPolicyLearner%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%2C%20Union%7BDataFrames.AbstractDataFrame%2C%20AbstractMatrix%7B%3C%3AReal%7D%7D%7D>`
 
         Examples
         --------
@@ -428,7 +629,7 @@ class PolicyLearner(SupervisedLearner):
         point in the features `X` as predicted by the learner.
 
         Julia Equivalent:
-        `IAI.predict_treatment_rank <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_treatment_rank>`
+        `IAI.predict_treatment_rank <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_treatment_rank>`
 
         Examples
         --------
@@ -447,7 +648,7 @@ class PolicyLearner(SupervisedLearner):
         of the learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_treatment_outcome <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_treatment_outcome>`
+        `IAI.predict_treatment_outcome <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_treatment_outcome>`
 
         Examples
         --------
@@ -466,7 +667,7 @@ class GridSearch(Learner):
     """Controls grid search over parameter combinations in `params` for `lnr`.
 
     Julia Equivalent:
-    `IAI.GridSearch <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.GridSearch>`
+    `IAI.GridSearch <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.GridSearch>`
 
     Examples
     --------
@@ -553,7 +754,7 @@ class GridSearch(Learner):
         the grid.
 
         Julia Equivalent:
-        `IAI.get_learner <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_learner>`
+        `IAI.get_learner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_learner>`
 
         Examples
         --------
@@ -568,7 +769,7 @@ class GridSearch(Learner):
         """Return the best parameter combination from the grid.
 
         Julia Equivalent:
-        `IAI.get_best_params <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_best_params>`
+        `IAI.get_best_params <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_best_params>`
 
         Examples
         --------
@@ -591,7 +792,7 @@ class GridSearch(Learner):
         """Return a summary of the results from the grid search.
 
         Julia Equivalent:
-        `IAI.get_grid_result_summary <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_grid_result_summary>`
+        `IAI.get_grid_result_summary <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_grid_result_summary>`
 
         Examples
         --------
@@ -606,7 +807,7 @@ class GridSearch(Learner):
         """Return a `list` of `dict`s detailing the results of the grid search.
 
         Julia Equivalent:
-        `IAI.get_grid_result_details <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_grid_result_details>`
+        `IAI.get_grid_result_details <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_grid_result_details>`
 
         Examples
         --------
@@ -629,11 +830,29 @@ class GridSearch(Learner):
 
         return details
 
+    def fit(self, *args, **kwargs):
+        """Fit a grid with data `X` and `y`.
+
+        Julia Equivalent:
+        `IAI.fit! <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit%21-Tuple%7BGridSearch%7D>`
+
+        Examples
+        --------
+        >>> grid.fit(X, *y, **kwargs)
+
+        Parameters
+        ----------
+        Refer to the documentation on
+        `data preparation <https://docs.interpretable.ai/v3.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        for information on how to format and supply the data.
+        """
+        return super().fit(*args, **kwargs)
+
     def fit_cv(self, *args, **kwargs):
         """Fit a grid with data `X` and `y` using k-fold cross-validation.
 
         Julia Equivalent:
-        `IAI.fit_cv! <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit_cv!>`
+        `IAI.fit_cv! <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_cv%21-Tuple%7BGridSearch%7D>`
 
         Examples
         --------
@@ -642,7 +861,7 @@ class GridSearch(Learner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v3.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v3.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         _IAI.fit_cv_convert(self._jl_obj, *args, **kwargs)
@@ -653,7 +872,7 @@ class GridSearch(Learner):
         cross-validation and impute missing values in `X`.
 
         Julia Equivalent:
-        `IAI.fit_transform_cv! <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit_transform_cv!>`
+        `IAI.fit_transform_cv! <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_transform_cv!>`
 
         Examples
         --------
@@ -662,7 +881,7 @@ class GridSearch(Learner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v3.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v3.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         self._check_delegate("fit_transform", "fit_transform_cv")
@@ -698,6 +917,49 @@ class GridSearch(Learner):
         return _IAI.write_questionnaire_convert(filename, self._jl_obj,
                                                 **kwargs)
 
+    def MultiQuestionnaire(self, **args):
+        """Construct a
+        :meth:`interpretableai.iai.MultiQuestionnaire`
+        containing the final fitted learner from the trained grid search as
+        well as the learner found for each parameter combination.
+
+        Julia Equivalent:
+        `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.MultiQuestionnaire-Tuple%7BGridSearch%7D>`
+
+        Examples
+        --------
+        >>> grid.MultiQuestionnaire()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.0 or higher.
+        """
+        self._check_delegate("Questionnaire", "MultiQuestionnaire")
+        _requires_iai_version("2.0.0", "MultiQuestionnaire")
+        return MultiQuestionnaire(self._jl_obj, **args)
+
+    def MultiTreePlot(self, **args):
+        """Construct a
+        :meth:`interpretableai.iai.MultiTreePlot`
+        containing the final fitted learner from the trained grid search as
+        well as the learner found for each parameter combination.
+
+        Julia Equivalent:
+        `IAI.MultiTreePlot <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.MultiTreePlot-Tuple%7BGridSearch%7D>`
+
+        Examples
+        --------
+        >>> grid.MultiTreePlot()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.0 or higher.
+        """
+        self._check_delegate("TreePlot", "MultiTreePlot")
+        _requires_iai_version("2.0.0", "MultiTreePlot")
+        from .iai import MultiTreePlot
+        return MultiTreePlot(self._jl_obj, **args)
+
     def show_questionnaire(self, *args, **kwargs):  # pragma: no cover
         self._check_delegate("show_questionnaire", "show_questionnaire")
         if _iai_version_less_than("2.0.0"):
@@ -726,7 +988,7 @@ class GridSearch(Learner):
         type : str
             The type of plot to construct, either `"validation"` or
             `"importance"`. For more information refer to the
-            `Julia documentation for plotting grid search results <https://docs.interpretable.ai/v3.0.0/OptimalFeatureSelection/visualization/#Plotting-Grid-Search-Results-1>`.
+            `Julia documentation for plotting grid search results <https://docs.interpretable.ai/v3.1.0/OptimalFeatureSelection/visualization/#Plotting-Grid-Search-Results-1>`.
 
         Compatibility
         -------------
@@ -785,21 +1047,19 @@ class ROCCurve():
     """Container for ROC curve information.
 
     Julia Equivalent:
-    `IAI.ROCCurve <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.ROCCurve>`
+    `IAI.ROCCurve <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.ROCCurve>`
 
     Examples
     --------
-    Construct an
-    `ROCCurve <https://docs.interpretable.ai/v3.0.0/IAI-Python/reference/#ROCCurve>`
-    using trained `lnr` on the features `X` and labels `y`:
 
-    >>> iai.ROCCurve(lnr, X, y)
-
-    Construct an
-    `ROCCurve <https://docs.interpretable.ai/v3.0.0/IAI-Python/reference/#ROCCurve>`
+    Construct a
+    :meth:`interpretableai.iai.ROCCurve`
     using predicted probabilities `probs` and true labels `y`, with
     probabilities indicating chance of predicting `positive_label`:
 
+    Julia Equivalent:
+    `IAI.ROCCurve <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.ROCCurve-Tuple%7BAbstractVector%7B%3C%3AReal%7D%2C%20AbstractVector%7D>`
+
     >>> iai.ROCCurve(probs, y, positive_label=positive_label)
     """
     def __init__(self, *args, **kwargs):
@@ -813,10 +1073,21 @@ class ROCCurve():
             if not isinstance(lnr, ClassificationLearner):
                 raise TypeError("lnr is not a ClassificationLearner")
 
+            _warnings.warn(
+                "'iai.ROCCurve(lnr, X, y)' is deprecated, use " +
+                "`lnr.ROCCurve(X, y)`",
+                FutureWarning
+            )
+
             self._jl_obj = _IAI.ROCCurve_convert(lnr._jl_obj, *args, **kwargs)
         else:
-            _requires_iai_version("2.0.0", "ROCCurve",
-                                  "with probabilities and true labels")
+            # Check if the first argument is a Julia object
+            # We need a ref to the `jlwrap` class, so get it from the
+            # `ROCCurve_convert` function we are about to call
+            if (len(args) > 0 and
+                    not isinstance(args[0], type(_IAI.ROCCurve_convert))):
+                _requires_iai_version("2.0.0", "ROCCurve",
+                                      "with probabilities and true labels")
             self._jl_obj = _IAI.ROCCurve_convert(*args, **kwargs)
 
     def __repr__(self):
@@ -830,7 +1101,7 @@ class ROCCurve():
         `filename` as HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_html-Tuple%7BAny,%20ROCCurve%7D>`
 
         Examples
         --------
@@ -847,7 +1118,7 @@ class ROCCurve():
         """Visualize the ROC curve in the browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.show_in_browser-Tuple%7BROCCurve%7D>`
 
         Examples
         --------
@@ -864,7 +1135,7 @@ class ROCCurve():
         - `auc`: the area-under-the-curve (AUC)
 
         Julia Equivalent:
-        `IAI.get_roc_curve_data <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_roc_curve_data>`
+        `IAI.get_roc_curve_data <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_roc_curve_data>`
 
         Examples
         --------
@@ -917,7 +1188,7 @@ class SurvivalCurve():
     time `t`.
 
     Julia Equivalent:
-    `IAI.SurvivalCurve <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.SurvivalCurve>`
+    `IAI.SurvivalCurve <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.SurvivalCurve>`
     """
     def __init__(self, jl_curve):
         self._jl_obj = jl_curve
@@ -936,10 +1207,27 @@ class SurvivalCurve():
         - `'coefs'`: the probablility for each breakpoint on the curve
 
         Julia Equivalent:
-        `IAI.get_survival_curve_data <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.get_survival_curve_data>`
+        `IAI.get_survival_curve_data <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_survival_curve_data>`
 
         Examples
         --------
         >>> curve.get_data()
         """
         return _IAI.get_survival_curve_data_convert(self._jl_obj)
+
+    def predict_expected_survival_time(self):
+        """Return the expected survival time according to the curve
+
+        Julia Equivalent:
+        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_expected_survival_time-Tuple%7BSurvivalCurve%7D>`
+
+        Examples
+        --------
+        >>> curve.predict_expected_survival_time()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "predict_expected_survival_time")
+        return _IAI.predict_expected_survival_time_convert(self._jl_obj)
