@@ -1,18 +1,24 @@
 from .iai import _IAI, _requires_iai_version, GridSearch
 from .iaibase import (Learner, SupervisedLearner, ClassificationLearner,
                       RegressionLearner, SurvivalLearner, PrescriptionLearner,
-                      PolicyLearner, SurvivalCurve)
+                      PolicyLearner, SurvivalCurve, AbstractVisualization,
+                      Questionnaire)
 import pandas as _pd
+import warnings as _warnings
 
 
 class TreeLearner(SupervisedLearner):
-    """Abstract type encompassing all tree-based learners."""
+    """Abstract type encompassing all tree-based learners.
+
+    Julia Equivalent:
+    `IAI.TreeLearner <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.TreeLearner>`
+    """
 
     def get_num_nodes(self):
         """Return the number of nodes in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_nodes <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_num_nodes>`
+        `IAI.get_num_nodes <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_num_nodes>`
 
         Examples
         --------
@@ -24,7 +30,7 @@ class TreeLearner(SupervisedLearner):
         """Return `True` if node `node_index` in the trained learner is a leaf.
 
         Julia Equivalent:
-        `IAI.is_leaf <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_leaf>`
+        `IAI.is_leaf <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_leaf>`
 
         Examples
         --------
@@ -36,7 +42,7 @@ class TreeLearner(SupervisedLearner):
         """Return the depth of node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_depth <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_depth>`
+        `IAI.get_depth <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_depth>`
 
         Examples
         --------
@@ -49,7 +55,7 @@ class TreeLearner(SupervisedLearner):
         in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_samples <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_num_samples>`
+        `IAI.get_num_samples <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_num_samples>`
 
         Examples
         --------
@@ -62,7 +68,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_lower_child <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_lower_child>`
+        `IAI.get_lower_child <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_lower_child>`
 
         Examples
         --------
@@ -75,7 +81,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_parent <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_parent>`
+        `IAI.get_parent <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_parent>`
 
         Examples
         --------
@@ -88,7 +94,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_upper_child <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_upper_child>`
+        `IAI.get_upper_child <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_upper_child>`
 
         Examples
         --------
@@ -101,7 +107,7 @@ class TreeLearner(SupervisedLearner):
         parallel split.
 
         Julia Equivalent:
-        `IAI.is_parallel_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_parallel_split>`
+        `IAI.is_parallel_split <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_parallel_split>`
 
         Examples
         --------
@@ -114,7 +120,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split.
 
         Julia Equivalent:
-        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_hyperplane_split>`
+        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_hyperplane_split>`
 
         Examples
         --------
@@ -127,7 +133,7 @@ class TreeLearner(SupervisedLearner):
         categoric split.
 
         Julia Equivalent:
-        `IAI.is_categoric_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_categoric_split>`
+        `IAI.is_categoric_split <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_categoric_split>`
 
         Examples
         --------
@@ -140,7 +146,7 @@ class TreeLearner(SupervisedLearner):
         ordinal split.
 
         Julia Equivalent:
-        `IAI.is_ordinal_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_ordinal_split>`
+        `IAI.is_ordinal_split <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_ordinal_split>`
 
         Examples
         --------
@@ -153,7 +159,7 @@ class TreeLearner(SupervisedLearner):
         categoric/parallel split.
 
         Julia Equivalent:
-        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
+        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
 
         Examples
         --------
@@ -166,7 +172,7 @@ class TreeLearner(SupervisedLearner):
         categoric/ordinal split.
 
         Julia Equivalent:
-        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
+        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
 
         Examples
         --------
@@ -179,7 +185,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.missing_goes_lower <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.missing_goes_lower>`
+        `IAI.missing_goes_lower <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.missing_goes_lower>`
 
         Examples
         --------
@@ -192,7 +198,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_feature <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_split_feature>`
+        `IAI.get_split_feature <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_split_feature>`
 
         Examples
         --------
@@ -205,7 +211,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_threshold <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_split_threshold>`
+        `IAI.get_split_threshold <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_split_threshold>`
 
         Examples
         --------
@@ -218,7 +224,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_categories <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_split_categories>`
+        `IAI.get_split_categories <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_split_categories>`
 
         Examples
         --------
@@ -231,7 +237,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split at  node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_split_weights>`
+        `IAI.get_split_weights <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_split_weights>`
 
         Examples
         --------
@@ -244,7 +250,7 @@ class TreeLearner(SupervisedLearner):
         features `X` falls.
 
         Julia Equivalent:
-        `IAI.apply <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.apply>`
+        `IAI.apply <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.apply>`
 
         Examples
         --------
@@ -257,7 +263,7 @@ class TreeLearner(SupervisedLearner):
         each node in the learner.
 
         Julia Equivalent:
-        `IAI.apply_nodes <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.apply_nodes>`
+        `IAI.apply_nodes <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.apply_nodes>`
 
         Examples
         --------
@@ -271,7 +277,7 @@ class TreeLearner(SupervisedLearner):
         the features `X` passes through the `j`th node in the learner.
 
         Julia Equivalent:
-        `IAI.decision_path <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.decision_path>`
+        `IAI.decision_path <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.decision_path>`
 
         Examples
         --------
@@ -284,7 +290,7 @@ class TreeLearner(SupervisedLearner):
         features `X`.
 
         Julia Equivalent:
-        `IAI.print_path <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.print_path>`
+        `IAI.print_path <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.print_path>`
 
         Examples
         --------
@@ -295,12 +301,14 @@ class TreeLearner(SupervisedLearner):
     def write_png(self, filename, **kwargs):  # pragma: no cover
         """Write learner to `filename` as a PNG image.
 
-        Requires
-        [GraphViz](http://www.graphviz.org/)
-        be installed and on the system `PATH`.
+        Before using this function, either run
+        :meth:`interpretableai.iai.load_graphviz`
+        or ensure that
+        [Graphviz](http://www.graphviz.org/)
+        is installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_png <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_png>`
+        `IAI.write_png <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_png>`
 
         Examples
         --------
@@ -311,12 +319,14 @@ class TreeLearner(SupervisedLearner):
     def write_pdf(self, filename, **kwargs):  # pragma: no cover
         """Write learner to `filename` as a PDF image.
 
-        Requires
-        [GraphViz](http://www.graphviz.org/)
-        be installed and on the system `PATH`.
+        Before using this function, either run
+        :meth:`interpretableai.iai.load_graphviz`
+        or ensure that
+        [Graphviz](http://www.graphviz.org/)
+        is installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_pdf <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_pdf>`
+        `IAI.write_pdf <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_pdf>`
 
         Compatibility
         -------------
@@ -332,12 +342,14 @@ class TreeLearner(SupervisedLearner):
     def write_svg(self, filename, **kwargs):  # pragma: no cover
         """Write learner to `filename` as an SVG image.
 
-        Requires
-        [GraphViz](http://www.graphviz.org/)
-        be installed and on the system `PATH`.
+        Before using this function, either run
+        :meth:`interpretableai.iai.load_graphviz`
+        or ensure that
+        [Graphviz](http://www.graphviz.org/)
+        is installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_svg <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_svg>`
+        `IAI.write_svg <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_svg>`
 
         Compatibility
         -------------
@@ -355,7 +367,7 @@ class TreeLearner(SupervisedLearner):
         [.dot format](http://www.graphviz.org/content/dot-language/).
 
         Julia Equivalent:
-        `IAI.write_dot <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_dot>`
+        `IAI.write_dot <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_dot>`
 
         Examples
         --------
@@ -363,12 +375,30 @@ class TreeLearner(SupervisedLearner):
         """
         return _IAI.write_dot_convert(filename, self._jl_obj, **kwargs)
 
+    def TreePlot(self, *args, **kwargs):
+        """Construct a
+        :meth:`interpretableai.iai.TreePlot`
+        based on the trained learner.
+
+        Julia Equivalent:
+        `IAI.TreePlot <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.TreePlot-Tuple%7BTreeLearner%7D>`
+
+        Examples
+        --------
+        >>> iai.TreePlot(lnr, **kwargs)
+
+        Compatibility
+        -------------
+        Requires IAI version 1.1 or higher.
+        """
+        return TreePlot(self._jl_obj, **kwargs)
+
     def write_html(self, filename, **kwargs):
         """Write interactive browser visualization of learner to `filename` as
         HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_html-Tuple%7BAny%2C%20TreeLearner%7D>`
 
         Examples
         --------
@@ -380,7 +410,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive visualization of learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.show_in_browser-Tuple%7BTreeLearner%7D>`
 
         Examples
         --------
@@ -388,12 +418,30 @@ class TreeLearner(SupervisedLearner):
         """
         return _IAI.show_in_browser_convert(self._jl_obj, **kwargs)
 
+    def Questionnaire(self, **kwargs):
+        """Construct a
+        :meth:`interpretableai.iai.Questionnaire`
+        based on the trained learner.
+
+        Julia Equivalent:
+        `IAI.Questionnaire <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.Questionnaire-Tuple%7BTreeLearner%7D>`
+
+        Examples
+        --------
+        >>> iai.Questionnaire(lnr, **kwargs)
+
+        Compatibility
+        -------------
+        Requires IAI version 1.1 or higher.
+        """
+        return Questionnaire(self._jl_obj, **kwargs)
+
     def write_questionnaire(self, filename, **kwargs):
         """Write interactive questionnaire based on learner to `filename` as
         HTML.
 
         Julia Equivalent:
-        `IAI.write_questionnaire <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_questionnaire>`
+        `IAI.write_questionnaire <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_questionnaire-Tuple%7BAny%2C%20TreeLearner%7D>`
 
         Examples
         --------
@@ -406,7 +454,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive questionnaire based on learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_questionnaire <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.show_questionnaire>`
+        `IAI.show_questionnaire <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.show_questionnaire-Tuple%7BTreeLearner%7D>`
 
         Examples
         --------
@@ -414,12 +462,36 @@ class TreeLearner(SupervisedLearner):
         """
         return _IAI.show_questionnaire_convert(self._jl_obj, **kwargs)
 
+    def variable_importance(self, *args, **kwargs):
+        """Calculate the variable importance for the learner (see
+        :meth:`interpretableai.iai.Learner.variable_importance`).
+
+        Julia Equivalent:
+        `IAI.variable_importance <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.variable_importance-Tuple%7BTreeLearner%7D>`
+
+        Examples
+        --------
+        Calculate the variable_importance for the learner.
+
+        >>> lnr.variable_importance(**kwargs)
+
+        Calculate the variable_importance for the learner on new samples `X`.
+
+        >>> lnr.variable_importance(X, **kwargs)
+
+        Calculate the variable_importance for the learner on new data `X` and
+        `y`.
+
+        >>> lnr.variable_importance(X, *y, **kwargs)
+        """
+        return super().variable_importance(*args, **kwargs)
+
     def variable_importance_similarity(self, new_lnr, *args, **kwargs):
         """Calculate similarity between this learner and another tree learner
         using variable importance scores.
 
         Julia Equivalent:
-        `IAI.variable_importance_similarity <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.variable_importance_similarity>`
+        `IAI.variable_importance_similarity <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.variable_importance_similarity>`
 
         Examples
         --------
@@ -449,7 +521,7 @@ class TreeLearner(SupervisedLearner):
         than the tree with the best training objective.
 
         Julia Equivalent:
-        `IAI.get_tree <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_tree>`
+        `IAI.get_tree <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_tree>`
 
         Examples
         --------
@@ -469,6 +541,9 @@ class TreeLearner(SupervisedLearner):
 class ClassificationTreeLearner(ClassificationLearner):
     """Abstract type encompassing all tree-based learners with classification
     leaves.
+
+    Julia Equivalent:
+    `IAI.ClassificationTreeLearner <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.ClassificationTreeLearner>`
     """
 
     def get_classification_label(self, node_index, **kwargs):
@@ -476,7 +551,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         learner.
 
         Julia Equivalent:
-        `IAI.get_classification_label <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_classification_label>`
+        `IAI.get_classification_label <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_classification_label>`
 
         Examples
         --------
@@ -490,7 +565,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_classification_proba <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_classification_proba>`
+        `IAI.get_classification_proba <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_classification_proba>`
 
         Examples
         --------
@@ -504,7 +579,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.ClassificationTask%7D%2CInt64%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BClassificationTreeLearner%2C%20Int64%7D>`
 
         Examples
         --------
@@ -523,7 +598,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         prediction at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.ClassificationTask%7D%2CInt64%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BClassificationTreeLearner%2C%20Int64%7D>`
 
         Examples
         --------
@@ -544,7 +619,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         will be simplified after all changes have been made.
 
         Julia Equivalent:
-        `IAI.set_threshold! <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.set_threshold!>`
+        `IAI.set_threshold! <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.set_threshold!>`
 
         Examples
         --------
@@ -557,7 +632,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         """Show the probability of `display_label` when visualizing learner.
 
         Julia Equivalent:
-        `IAI.set_display_label! <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.set_display_label!>`
+        `IAI.set_display_label! <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.set_display_label!>`
 
         Examples
         --------
@@ -571,7 +646,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         predicted label when visualizing learner.
 
         Julia Equivalent:
-        `IAI.reset_display_label! <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.reset_display_label!>`
+        `IAI.reset_display_label! <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.reset_display_label!>`
 
         Examples
         --------
@@ -584,6 +659,9 @@ class ClassificationTreeLearner(ClassificationLearner):
 class RegressionTreeLearner(RegressionLearner):
     """Abstract type encompassing all tree-based learners with regression
     leaves.
+
+    Julia Equivalent:
+    `IAI.RegressionTreeLearner <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.RegressionTreeLearner>`
     """
 
     def get_regression_constant(self, node_index, **kwargs):
@@ -591,7 +669,7 @@ class RegressionTreeLearner(RegressionLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BRegressionTreeLearner%2C%20Int64%7D>`
 
         Examples
         --------
@@ -605,7 +683,7 @@ class RegressionTreeLearner(RegressionLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BRegressionTreeLearner%2C%20Int64%7D>`
 
         Examples
         --------
@@ -617,15 +695,18 @@ class RegressionTreeLearner(RegressionLearner):
 
 class SurvivalTreeLearner(SurvivalLearner):
     """Abstract type encompassing all tree-based learners with survival leaves.
+
+    Julia Equivalent:
+    `IAI.SurvivalTreeLearner <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.SurvivalTreeLearner>`
     """
 
     def get_survival_curve(self, node_index, **kwargs):
         """Return the
-        `SurvivalCurve <https://docs.interpretable.ai/v3.0.0/IAI-Python/reference/#SurvivalCurve>`
+        :meth:`interpretableai.iai.SurvivalCurve`
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_curve <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_survival_curve>`
+        `IAI.get_survival_curve <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_survival_curve>`
 
         Examples
         --------
@@ -640,7 +721,7 @@ class SurvivalTreeLearner(SurvivalLearner):
         the trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_expected_time <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_survival_expected_time>`
+        `IAI.get_survival_expected_time <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_survival_expected_time>`
 
         Examples
         --------
@@ -659,7 +740,7 @@ class SurvivalTreeLearner(SurvivalLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_hazard <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_survival_hazard>`
+        `IAI.get_survival_hazard <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_survival_hazard>`
 
         Examples
         --------
@@ -678,7 +759,7 @@ class SurvivalTreeLearner(SurvivalLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.SurvivalTask%7D%2CInt64%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BSurvivalTreeLearner%2C%20Int64%7D>`
 
         Examples
         --------
@@ -697,7 +778,7 @@ class SurvivalTreeLearner(SurvivalLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.SurvivalTask%7D%2CInt64%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BSurvivalTreeLearner%2C%20Int64%7D>`
 
         Examples
         --------
@@ -715,6 +796,9 @@ class SurvivalTreeLearner(SurvivalLearner):
 class PrescriptionTreeLearner(PrescriptionLearner):
     """Abstract type encompassing all tree-based learners with prescription
     leaves.
+
+    Julia Equivalent:
+    `IAI.PrescriptionTreeLearner <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.PrescriptionTreeLearner>`
     """
 
     def get_prescription_treatment_rank(self, node_index, **kwargs):
@@ -722,7 +806,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
+        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
 
         Examples
         --------
@@ -737,7 +821,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BPrescriptionTreeLearner%2C%20Int64%2C%20Any%7D>`
 
         Examples
         --------
@@ -751,7 +835,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         `treatment` at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BPrescriptionTreeLearner%2C%20Int64%2C%20Any%7D>`
 
         Examples
         --------
@@ -763,6 +847,9 @@ class PrescriptionTreeLearner(PrescriptionLearner):
 
 class PolicyTreeLearner(PolicyLearner):
     """Abstract type encompassing all tree-based learners with policy leaves.
+
+    Julia Equivalent:
+    `IAI.PolicyTreeLearner <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.PolicyTreeLearner>`
     """
 
     def get_policy_treatment_rank(self, node_index, **kwargs):
@@ -770,7 +857,7 @@ class PolicyTreeLearner(PolicyLearner):
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
+        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
 
         Examples
         --------
@@ -789,7 +876,7 @@ class PolicyTreeLearner(PolicyLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_policy_treatment_outcome <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_policy_treatment_outcome>`
+        `IAI.get_policy_treatment_outcome <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_policy_treatment_outcome>`
 
         Examples
         --------
@@ -804,56 +891,16 @@ class PolicyTreeLearner(PolicyLearner):
                                                          node_index, **kwargs)
 
 
-class AbstractVisualization():
-    """Abstract type encompassing objects related to visualization. """
-    def __init__(self, jl_obj):
-        self._jl_obj = jl_obj
-
-    def __repr__(self):
-        return _IAI.string(self._jl_obj)
-
-    def _repr_html_(self):
-        return _IAI.to_html(self._jl_obj)
-
-    def write_html(self, filename, **kwargs):
-        """Write interactive browser visualization to `filename` as HTML.
-
-        Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_html>`
-
-        Examples
-        --------
-        >>> treeplot.write_html(filename, **kwargs)
-        """
-        return _IAI.write_html_convert(filename, self._jl_obj, **kwargs)
-
-    def show_in_browser(self, **kwargs):  # pragma: no cover
-        """Show interactive visualization in default browser.
-
-        Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.show_in_browser>`
-
-        Examples
-        --------
-        >>> treeplot.show_in_browser(**kwargs)
-        """
-        return _IAI.show_in_browser_convert(self._jl_obj, **kwargs)
-
-
 class TreePlot(AbstractVisualization):
-    """Specify an interactive tree visualization of `lnr`.
+    """Specifies an interactive tree visualization.
 
     Julia Equivalent:
-    `IAI.TreePlot <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.TreePlot>`
-
-    Examples
-    --------
-    >>> iai.TreePlot(lnr, **kwargs)
+    `IAI.TreePlot <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.TreePlot-Tuple%7BTreeLearner%7D>`
 
     Parameters
     ----------
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v3.0.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v3.1.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -862,95 +909,33 @@ class TreePlot(AbstractVisualization):
     """
     def __init__(self, lnr, *args, **kwargs):
         _requires_iai_version("1.1.0", "TreePlot")
-        jl_obj = _IAI.TreePlot_convert(lnr._jl_obj, *args, **kwargs)
-        super().__init__(jl_obj)
 
-
-class Questionnaire(AbstractVisualization):
-    """Specify an interactive questionnaire of `lnr`.
-
-    Julia Equivalent:
-    `IAI.Questionnaire <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.Questionnaire>`
-
-    Examples
-    --------
-    >>> iai.Questionnaire(lnr, **kwargs)
-
-    Parameters
-    ----------
-
-    Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v3.0.0/IAITrees/advanced/#Advanced-Visualization-1>`
-    for available parameters.
-
-    Compatibility
-    -------------
-    Requires IAI version 1.1 or higher.
-    """
-    def __init__(self, lnr, **kwargs):
-        _requires_iai_version("1.1.0", "Questionnaire")
-        jl_obj = _IAI.Questionnaire_convert(lnr._jl_obj, **kwargs)
-        super().__init__(jl_obj)
-
-
-class MultiQuestionnaire(AbstractVisualization):
-    """Specify an interactive questionnaire of multiple tree learners
-
-    Julia Equivalent:
-    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
-
-    Examples
-    --------
-    Constructs an interactive questionnaire using multiple tree learners from
-    specified questions. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v3.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
-    for more information.
-
-    >>> iai.MultiQuestionnaire(questions)
-
-    Constructs an interactive questionnaire containing the final fitted learner
-    from trained grid search as well as the learner found for each parameter
-    combination.
-
-    >>> iai.MultiQuestionnaire(grid)
-
-    Compatibility
-    -------------
-    Requires IAI version 1.1 or higher.
-    """
-    def __init__(self, *args):
-        if len(args) > 0 and isinstance(args[0], GridSearch):
-            _requires_iai_version("2.0.0", "MultiQuestionnaire")
-            args = list(args)
-            grid = args.pop(0)
-            jl_obj = _IAI.MultiQuestionnaire_convert(grid._jl_obj, *args)
+        if isinstance(lnr, Learner):
+            _warnings.warn(
+                "'iai.TreePlot(lnr)' is deprecated, use `lnr.TreePlot(...)`",
+                FutureWarning
+            )
+            jl_obj = _IAI.TreePlot_convert(lnr._jl_obj, *args, **kwargs)
         else:
-            _requires_iai_version("1.1.0", "MultiQuestionnaire")
-            jl_obj = _IAI.MultiQuestionnaire_convert(*args)
+            jl_obj = _IAI.TreePlot_convert(lnr, *args, **kwargs)
         super().__init__(jl_obj)
 
 
 class MultiTreePlot(AbstractVisualization):
     """Specify an interactive tree visualization of multiple tree learners
 
-    Julia Equivalent:
-    `IAI.MultiTreePlot <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.MultiTreePlot>`
-
     Examples
     --------
     Constructs an interactive tree visualization using multiple tree learners
     from specified questions. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v3.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v3.1.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
+    Julia Equivalent:
+    `IAI.MultiTreePlot <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.MultiTreePlot-Tuple%7BPair%7D>`
+
     >>> iai.MultiTreePlot(questions)
 
-    Constructs an interactive tree visualization containing the final fitted
-    learner from trained grid search as well as the learner found for each
-    parameter combination.
-
-    >>> iai.MultiTreePlot(grid)
-
     Compatibility
     -------------
     Requires IAI version 1.1 or higher.
@@ -960,7 +945,14 @@ class MultiTreePlot(AbstractVisualization):
             _requires_iai_version("2.0.0", "MultiTreePlot")
             args = list(args)
             grid = args.pop(0)
-            jl_obj = _IAI.MultiQuestionnaire_convert(grid._jl_obj, *args)
+
+            _warnings.warn(
+                "'iai.MultiTreePlot(grid, ...)' is deprecated, use " +
+                "`grid.MultiTreePlot(...)`",
+                FutureWarning
+            )
+
+            jl_obj = _IAI.MultiTreePlot_convert(grid._jl_obj, *args)
         else:
             _requires_iai_version("1.1.0", "MultiTreePlot")
             jl_obj = _IAI.MultiTreePlot_convert(*args)
@@ -974,11 +966,11 @@ class SimilarityComparison(AbstractVisualization):
     `deviations`.
 
     Refer to the
-    `documentation on tree stability <https://docs.interpretable.ai/v3.0.0/IAITrees/stability/#Tree-Stability-1>`
+    `documentation on tree stability <https://docs.interpretable.ai/v3.1.0/IAITrees/stability/#Tree-Stability-1>`
     for more information.
 
     Julia Equivalent:
-    `IAI.SimilarityComparison <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.SimilarityComparison>`
+    `IAI.SimilarityComparison <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.SimilarityComparison>`
 
     Examples
     --------
@@ -1003,7 +995,7 @@ class SimilarityComparison(AbstractVisualization):
         comparison, where a lower value indicates a better solution.
 
         Julia Equivalent:
-        `IAI.get_train_errors <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_train_errors>`
+        `IAI.get_train_errors <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_train_errors>`
 
         Examples
         --------
@@ -1060,11 +1052,11 @@ class StabilityAnalysis(AbstractVisualization):
     """Conduct a stability analysis of the trees in a tree learner.
 
     Refer to the
-    `documentation on tree stability <https://docs.interpretable.ai/v3.0.0/IAITrees/stability/#Tree-Stability-1>`
+    `documentation on tree stability <https://docs.interpretable.ai/v3.1.0/IAITrees/stability/#Tree-Stability-1>`
     for more information.
 
     Julia Equivalent:
-    `IAI.StabilityAnalysis <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.StabilityAnalysis>`
+    `IAI.StabilityAnalysis <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.StabilityAnalysis>`
 
     Examples
     --------
@@ -1095,7 +1087,7 @@ class StabilityAnalysis(AbstractVisualization):
         along with their variable importance scores for each feature.
 
         Julia Equivalent:
-        `IAI.get_stability_results <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_stability_results>`
+        `IAI.get_stability_results <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_stability_results>`
 
         Examples
         --------
@@ -1113,7 +1105,7 @@ class StabilityAnalysis(AbstractVisualization):
         clustering of the best `num_trees` trees.
 
         Julia Equivalent:
-        `IAI.get_cluster_assignments <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_cluster_assignments>`
+        `IAI.get_cluster_assignments <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_cluster_assignments>`
 
         Examples
         --------
@@ -1132,7 +1124,7 @@ class StabilityAnalysis(AbstractVisualization):
         clustering of the best `num_trees` trees.
 
         Julia Equivalent:
-        `IAI.get_cluster_details <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_cluster_details>`
+        `IAI.get_cluster_details <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_cluster_details>`
 
         Examples
         --------
@@ -1151,7 +1143,7 @@ class StabilityAnalysis(AbstractVisualization):
         under the clustering of the best `num_trees` trees.
 
         Julia Equivalent:
-        `IAI.get_cluster_distances <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_cluster_distances>`
+        `IAI.get_cluster_distances <https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_cluster_distances>`
 
         Examples
         --------
