@@ -7,6 +7,9 @@ class MixedData(Categorical):
     `MixedData` features can represent a feature with either numeric/categoric
     or ordinal/categoric values.
 
+    Julia Equivalent:
+    `IAI.make_mixed_data <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.make_mixed_data>`
+
     Examples
     --------
     >>> iai.MixedData(values, ordinal_levels=None)
