@@ -6,7 +6,11 @@ import warnings as _warnings
 
 
 class OptimalTreeLearner(TreeLearner):
-    """Abstract type encompassing all optimal tree learners."""
+    """Abstract type encompassing all optimal tree learners.
+
+    Julia Equivalent:
+    `IAI.OptimalTreeLearner <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.OptimalTreeLearner>`
+    """
     def __init__(self, f, *args, refit_learner=None, **kwargs):
         if refit_learner:
             if not isinstance(refit_learner, Learner):
@@ -22,7 +26,7 @@ class OptimalTreeLearner(TreeLearner):
         supplied data.
 
         Julia Equivalent:
-        `IAI.refit_leaves! <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.refit_leaves!>`
+        `IAI.refit_leaves! <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.refit_leaves!>`
 
         Examples
         --------
@@ -53,7 +57,7 @@ class OptimalTreeLearner(TreeLearner):
         refit the models in each leaf of the tree using the supplied data.
 
         Julia Equivalent:
-        `IAI.copy_splits_and_refit_leaves! <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.copy_splits_and_refit_leaves!>`
+        `IAI.copy_splits_and_refit_leaves! <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.copy_splits_and_refit_leaves!>`
 
         Examples
         --------
@@ -89,7 +93,7 @@ class OptimalTreeLearner(TreeLearner):
         parameter and then prune the trees according to this value.
 
         Julia Equivalent:
-        `IAI.prune_trees! <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.prune_trees!>`
+        `IAI.prune_trees! <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.prune_trees!>`
 
         Examples
         --------
@@ -112,7 +116,7 @@ class OptimalTreeClassifier(OptimalTreeLearner, ClassificationTreeLearner):
     """Learner for training Optimal Classification Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeClassifier <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreeClassifier>`
+    `IAI.OptimalTreeClassifier <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.OptimalTreeClassifier>`
 
     Examples
     --------
@@ -131,7 +135,7 @@ class OptimalTreeRegressor(OptimalTreeLearner, RegressionTreeLearner):
     """Learner for training Optimal Regression Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeRegressor <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreeRegressor>`
+    `IAI.OptimalTreeRegressor <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.OptimalTreeRegressor>`
 
     Examples
     --------
@@ -150,7 +154,7 @@ class OptimalTreeSurvivalLearner(OptimalTreeLearner, SurvivalTreeLearner):
     """Learner for training Optimal Survival Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeSurvivalLearner <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreeSurvivalLearner>`
+    `IAI.OptimalTreeSurvivalLearner <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.OptimalTreeSurvivalLearner>`
 
     Examples
     --------
@@ -191,7 +195,7 @@ class OptimalTreePrescriptionMinimizer(OptimalTreeLearner,
     should aim to minimize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePrescriptionMinimizer <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMinimizer>`
+    `IAI.OptimalTreePrescriptionMinimizer <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMinimizer>`
 
     Examples
     --------
@@ -213,7 +217,7 @@ class OptimalTreePrescriptionMaximizer(OptimalTreeLearner,
     should aim to maximize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePrescriptionMaximizer <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMaximizer>`
+    `IAI.OptimalTreePrescriptionMaximizer <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMaximizer>`
 
     Examples
     --------
@@ -234,7 +238,7 @@ class OptimalTreePolicyMinimizer(OptimalTreeLearner, PolicyTreeLearner):
     should aim to minimize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePolicyMinimizer <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMinimizer>`
+    `IAI.OptimalTreePolicyMinimizer <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMinimizer>`
 
     Examples
     --------
@@ -260,7 +264,7 @@ class OptimalTreePolicyMaximizer(OptimalTreeLearner, PolicyTreeLearner):
     should aim to maximize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePolicyMaximizer <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMaximizer>`
+    `IAI.OptimalTreePolicyMaximizer <https://docs.interpretable.ai/v3.1.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMaximizer>`
 
     Examples
     --------
