@@ -9,7 +9,7 @@ def impute(*args, **kwargs):
     through grid search validation.
 
     Julia Equivalent:
-    `IAI.impute <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.impute>`
+    `IAI.impute <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.impute>`
 
     This method was deprecated in interpretableai 2.9.0. This is for
     consistency with the IAI v3.0.0 Julia release.
@@ -33,7 +33,7 @@ def impute_cv(*args, **kwargs):
     """Impute the missing values in `X` using cross validation.
 
     Julia Equivalent:
-    `IAI.impute_cv <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.impute_cv>`
+    `IAI.impute_cv <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.impute_cv>`
 
     This method was deprecated in interpretableai 2.9.0. This is for
     consistency with the IAI v3.0.0 Julia release.
@@ -57,7 +57,7 @@ class ImputationLearner(UnsupervisedLearner):
     """Abstract type containing all imputation learners.
 
     Julia Equivalent:
-    `IAI.ImputationLearner <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.ImputationLearner>`
+    `IAI.ImputationLearner <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.ImputationLearner>`
 
     Examples
     --------
@@ -81,18 +81,28 @@ class ImputationLearner(UnsupervisedLearner):
             jl_obj = _IAI.ImputationLearner_convert(*args, **kwargs)
         super().__init__(jl_obj)
 
+    def fit(self, *args, **kwargs):
+        """Fit a model using the parameters in learner and the data `X``
+        (see :meth:`interpretableai.iai.Learner.fit`).
+
+        Additional keyword arguments are available for fitting imputation
+        learners - please refer to the Julia documentation.
+
+        Julia Equivalent:
+        `IAI.fit! <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.fit%21-Tuple%7BLearner%7BIAIBase.ImputationTask%7D%7D>`
+
+        Examples
+        --------
+        >>> lnr.fit(X, **kwargs)
+        """
+        return super().fit(*args, **kwargs)
+
     def fit_transform(self, *args, **kwargs):
         """Fit the imputation learner using the training data `X` and impute the
         missing values in the training data.
 
-        Similar to calling
-        `fit <https://docs.interpretable.ai/v3.0.0/IAI-Python/reference/#fit-Tuple%7BLearner%7D>`
-        followed by
-        `transform <https://docs.interpretable.ai/v3.0.0/IAI-Python/reference/#transform%7BImputationLearner%7D>`
-        .
-
         Julia Equivalent:
-        `IAI.fit_transform! <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit_transform!>`
+        `IAI.fit_transform! <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_transform!>`
 
         Examples
         --------
@@ -101,7 +111,7 @@ class ImputationLearner(UnsupervisedLearner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v3.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v3.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         return _IAI.fit_transform_convert(self._jl_obj, *args, **kwargs)
@@ -111,7 +121,7 @@ class ImputationLearner(UnsupervisedLearner):
         the learner.
 
         Julia Equivalent:
-        `IAI.transform <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.transform>`
+        `IAI.transform <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.transform>`
 
         Examples
         --------
@@ -120,7 +130,7 @@ class ImputationLearner(UnsupervisedLearner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v3.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v3.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         return _IAI.transform_convert(self._jl_obj, *args, **kwargs)
@@ -131,7 +141,7 @@ class ImputationLearner(UnsupervisedLearner):
         `type`.
 
         Julia Equivalent:
-        `IAI.fit_and_expand! <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.fit_and_expand!>`
+        `IAI.fit_and_expand! <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.fit_and_expand%21>`
 
         Examples
         --------
@@ -140,7 +150,7 @@ class ImputationLearner(UnsupervisedLearner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v3.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v3.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
 
         Compatibility
@@ -156,7 +166,7 @@ class ImputationLearner(UnsupervisedLearner):
         according to `type`.
 
         Julia Equivalent:
-        `IAI.transform_and_expand <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.transform_and_expand>`
+        `IAI.transform_and_expand <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.transform_and_expand>`
 
         Examples
         --------
@@ -165,7 +175,7 @@ class ImputationLearner(UnsupervisedLearner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v3.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v3.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
 
         Compatibility
@@ -180,7 +190,7 @@ class OptKNNImputationLearner(ImputationLearner):
     """Learner for conducting optimal k-NN imputation.
 
     Julia Equivalent:
-    `IAI.OptKNNImputationLearner <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptKNNImputationLearner>`
+    `IAI.OptKNNImputationLearner <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.OptKNNImputationLearner>`
 
     Examples
     --------
@@ -200,7 +210,7 @@ class OptSVMImputationLearner(ImputationLearner):
     """Learner for conducting optimal SVM imputation.
 
     Julia Equivalent:
-    `IAI.OptSVMImputationLearner <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptSVMImputationLearner>`
+    `IAI.OptSVMImputationLearner <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.OptSVMImputationLearner>`
 
     Examples
     --------
@@ -220,7 +230,7 @@ class OptTreeImputationLearner(ImputationLearner):
     """Learner for conducting optimal tree-based imputation.
 
     Julia Equivalent:
-    `IAI.OptTreeImputationLearner <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.OptTreeImputationLearner>`
+    `IAI.OptTreeImputationLearner <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.OptTreeImputationLearner>`
 
     Examples
     --------
@@ -240,7 +250,7 @@ class SingleKNNImputationLearner(ImputationLearner):
     """Learner for conducting heuristic k-NN imputation.
 
     Julia Equivalent:
-    `IAI.SingleKNNImputationLearner <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.SingleKNNImputationLearner>`
+    `IAI.SingleKNNImputationLearner <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.SingleKNNImputationLearner>`
 
     Examples
     --------
@@ -260,7 +270,7 @@ class MeanImputationLearner(ImputationLearner):
     """Learner for conducting mean imputation.
 
     Julia Equivalent:
-    `IAI.MeanImputationLearnerer <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.MeanImputationLearner>`
+    `IAI.MeanImputationLearner <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.MeanImputationLearner>`
 
     Examples
     --------
@@ -280,7 +290,7 @@ class RandImputationLearner(ImputationLearner):
     """Learner for conducting random imputation.
 
     Julia Equivalent:
-    `IAI.RandImputationLearnerer <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.RandImputationLearner>`
+    `IAI.RandImputationLearner <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.RandImputationLearner>`
 
     Examples
     --------
@@ -300,7 +310,7 @@ class ZeroImputationLearner(ImputationLearner):
     """Learner for conducting zero-imputation.
 
     Julia Equivalent:
-    `IAI.ZeroImputationLearnerer <https://docs.interpretable.ai/v3.0.0/OptImpute/reference/#IAI.ZeroImputationLearner>`
+    `IAI.ZeroImputationLearner <https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.ZeroImputationLearner>`
 
     Examples
     --------
