@@ -29,9 +29,31 @@ def _process_estimators(f, propensity_type, outcome_type, *args,
              outcome_estimator=outcome_estimator, **kwargs)
 
 
-class CategoricalRewardEstimationLearner(SupervisedLearner):
+class RewardEstimationLearner(SupervisedLearner):
+    """Abstract type encompassing all learners for reward estimation.
+
+    Julia Equivalent:
+    `IAI.RewardEstimationLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.RewardEstimationLearner>`
+    """
+
+    def fit_predict(self, *args, **kwargs):  # pragma: no cover
+        """Fit a reward estimation model and return predicted counterfactual
+        rewards for each observation along with the scores of the internal
+        estimators during training.
+
+        Julia Equivalent:
+        `IAI.fit_predict! <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.fit_predict%21-Tuple%7BRewardEstimator%7D>`
+        """
+        raise NotImplementedError()
+
+
+class CategoricalRewardEstimationLearner(RewardEstimationLearner):
     """Abstract type encompassing all learners for reward estimation with
-    categorical treatments."""
+    categorical treatments.
+
+    Julia Equivalent:
+    `IAI.CategoricalRewardEstimationLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.CategoricalRewardEstimationLearner>`
+    """
 
     def fit_predict(self, *args, **kwargs):
         """Fit a reward estimation model and return predicted counterfactual
@@ -39,7 +61,7 @@ class CategoricalRewardEstimationLearner(SupervisedLearner):
         estimators during training.
 
         Julia Equivalent:
-        `IAI.fit_predict! <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.fit_predict!-Tuple%7BLearner%7BIAIBase.CategoricalRewardEstimationTask%7D%7D>`
+        `IAI.fit_predict! <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.fit_predict%21-Tuple%7BCategoricalRewardEstimator%7D>`
 
         Examples
         --------
@@ -68,7 +90,7 @@ class CategoricalRewardEstimationLearner(SupervisedLearner):
         observation in the supplied data.
 
         Julia Equivalent:
-        `IAI.predict <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict-Tuple%7BCategoricalRewardEstimator%7BT%7D%2520where%2520T%7D>`
+        `IAI.predict <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.predict-Tuple%7BCategoricalRewardEstimator%7D>`
 
         Examples
         --------
@@ -99,7 +121,7 @@ class CategoricalRewardEstimationLearner(SupervisedLearner):
         for each observation in the supplied data and predictions.
 
         Julia Equivalent:
-        `IAI.predict_reward <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict_reward-Tuple%7BCategoricalRewardEstimator%7BT%7D%2520where%2520T%7D>`
+        `IAI.predict_reward <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.predict_reward-Tuple%7BCategoricalRewardEstimator%7D>`
 
         Examples
         --------
@@ -135,7 +157,7 @@ class CategoricalRewardEstimationLearner(SupervisedLearner):
                         corresponding to each treatment
 
         Julia Equivalent:
-        `IAI.score <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.score-Tuple%7BCategoricalRewardEstimator%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s39%22%2C2%7D%2520where%2520var%22%23s39%22%3C%3AReal%7D%2CArray%7BT%2C1%7D%2520where%2520T%2CArray%7BT%2C1%7D%2520where%2520T%7D>`
+        `IAI.score <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.score-Tuple%7BCategoricalRewardEstimator%7D>`
 
         Examples
         --------
@@ -165,7 +187,7 @@ class CategoricalClassificationRewardEstimator(CategoricalRewardEstimationLearne
     classification outcomes.
 
     Julia Equivalent:
-    `IAI.CategoricalClassificationRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalClassificationRewardEstimator>`
+    `IAI.CategoricalClassificationRewardEstimator <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.CategoricalClassificationRewardEstimator>`
 
     Examples
     --------
@@ -196,7 +218,7 @@ class CategoricalRegressionRewardEstimator(CategoricalRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.CategoricalRegressionRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalRegressionRewardEstimator>`
+    `IAI.CategoricalRegressionRewardEstimator <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.CategoricalRegressionRewardEstimator>`
 
     Examples
     --------
@@ -226,7 +248,7 @@ class CategoricalSurvivalRewardEstimator(CategoricalRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.CategoricalSurvivalRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalSurvivalRewardEstimator>`
+    `IAI.CategoricalSurvivalRewardEstimator <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.CategoricalSurvivalRewardEstimator>`
 
     Examples
     --------
@@ -258,7 +280,7 @@ class EqualPropensityEstimator(ClassificationLearner):
     be randomly assigned.
 
     Julia Equivalent:
-    `IAI.EqualPropensityEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.EqualPropensityEstimator>`
+    `IAI.EqualPropensityEstimator <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.EqualPropensityEstimator>`
 
     Examples
     --------
@@ -274,9 +296,13 @@ class EqualPropensityEstimator(ClassificationLearner):
         super().__init__(jl_obj)
 
 
-class NumericRewardEstimationLearner(SupervisedLearner):
+class NumericRewardEstimationLearner(RewardEstimationLearner):
     """Abstract type encompassing all learners for reward estimation with
-    numeric treatments."""
+    numeric treatments.
+
+    Julia Equivalent:
+    `IAI.NumericRewardEstimationLearner <https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.NumericRewardEstimationLearner>`
+    """
 
     def fit_predict(self, *args, **kwargs):
         """Fit a reward estimation model and return predicted counterfactual
@@ -285,7 +311,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         estimator.
 
         Julia Equivalent:
-        `IAI.fit_predict! <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.fit_predict!-Tuple%7BLearner%7BIAIBase.NumericRewardEstimationTask%7D%7D>`
+        `IAI.fit_predict! <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.fit_predict%21-Tuple%7BNumericRewardEstimator%7D>`
 
         Examples
         --------
@@ -316,7 +342,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         observation in the supplied data.
 
         Julia Equivalent:
-        `IAI.predict <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict-Tuple%7BNumericRewardEstimator%7BT%7D%2520where%2520T%7D>`
+        `IAI.predict <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.predict-Tuple%7BNumericRewardEstimator%7D>`
 
         Examples
         --------
@@ -353,7 +379,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         for each observation in the supplied data and predictions.
 
         Julia Equivalent:
-        `IAI.predict_reward <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict_reward-Tuple%7BNumericRewardEstimator%7BT%7D%2520where%2520T%7D>`
+        `IAI.predict_reward <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.predict_reward-Tuple%7BNumericRewardEstimator%7D>`
 
         Examples
         --------
@@ -381,7 +407,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         the supplied data.
 
         Julia Equivalent:
-        `IAI.score <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.score-Tuple%7BNumericRewardEstimator%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s39%22%2C2%7D%2520where%2520var%22%23s39%22%3C%3AReal%7D%2CArray%7BT%2C1%7D%2520where%2520T%2CArray%7BT%2C1%7D%2520where%2520T%7D>`
+        `IAI.score <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.score-Tuple%7BNumericRewardEstimator%7D>`
 
         On IAI versions 2.2 and greater, returns a `dict` with the following
         entries:
@@ -423,7 +449,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         for the propensity/outcome estimation problems in the fitted learner.
 
         Julia Equivalent:
-        `IAI.get_estimation_densities <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.get_estimation_densities>`
+        `IAI.get_estimation_densities <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.get_estimation_densities>`
 
         Examples
         --------
@@ -443,7 +469,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         final tuned values.
 
         Julia Equivalent:
-        `IAI.tune_reward_kernel_bandwidth <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.tune_reward_kernel_bandwidth>`
+        `IAI.tune_reward_kernel_bandwidth <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.tune_reward_kernel_bandwidth>`
 
         Examples
         --------
@@ -463,7 +489,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         this bandwidth for the original data used to train the learner.
 
         Julia Equivalent:
-        `IAI.set_reward_kernel_bandwidth! <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.set_reward_kernel_bandwidth!>`
+        `IAI.set_reward_kernel_bandwidth! <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.set_reward_kernel_bandwidth!>`
 
         Examples
         --------
@@ -483,7 +509,7 @@ class NumericClassificationRewardEstimator(NumericRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.NumericClassificationRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericClassificationRewardEstimator>`
+    `IAI.NumericClassificationRewardEstimator <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.NumericClassificationRewardEstimator>`
 
     Examples
     --------
@@ -513,7 +539,7 @@ class NumericRegressionRewardEstimator(NumericRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.NumericRegressionRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericRegressionRewardEstimator>`
+    `IAI.NumericRegressionRewardEstimator <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.NumericRegressionRewardEstimator>`
 
     Examples
     --------
@@ -543,7 +569,7 @@ class NumericSurvivalRewardEstimator(NumericRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.NumericSurvivalRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericSurvivalRewardEstimator>`
+    `IAI.NumericSurvivalRewardEstimator <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.NumericSurvivalRewardEstimator>`
 
     Examples
     --------
@@ -573,6 +599,9 @@ def all_treatment_combinations(*args, **kwargs):
     or more treatment vectors, ready for use as `treatment_candidates` in
     `fit_predict!` or `predict`.
 
+    Julia Equivalent:
+    `IAI.all_treatment_combinations <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.all_treatment_combinations>`
+
     Examples
     --------
     >>> iai.all_treatment_combinations(*args, **kwargs)
@@ -588,6 +617,9 @@ def all_treatment_combinations(*args, **kwargs):
 def convert_treatments_to_numeric(*args, **kwargs):
     """Convert `treatments` from symbol/string format into numeric values.
 
+    Julia Equivalent:
+    `IAI.convert_treatments_to_numeric <https://docs.interpretable.ai/v3.1.0/RewardEstimation/reference/#IAI.convert_treatments_to_numeric>`
+
     Examples
     --------
     >>> iai.convert_treatments_to_numeric(treatments)
@@ -603,16 +635,6 @@ def convert_treatments_to_numeric(*args, **kwargs):
 # DEPRECATED
 
 
-class RewardEstimationLearner(CategoricalRewardEstimationLearner):
-    """Abstract type encompassing all learners for reward estimation with
-    categorical treatments.
-
-    This class was deprecated and renamed to CategoricalRewardEstimationLearner
-    in interpretableai 2.3.0. This is for consistency with the IAI v2.1.0 Julia
-    release.
-    """
-
-
 class CategoricalRewardEstimator(CategoricalRewardEstimationLearner):
     """Learner for reward estimation with categorical treatments.
 
@@ -637,7 +659,7 @@ class CategoricalRewardEstimator(CategoricalRewardEstimationLearner):
     """
     def __init__(self, *args, propensity_estimator=None,
                  outcome_estimator=None, **kwargs):
-        if not _iai_version_less_than("2.3.0"):
+        if not _iai_version_less_than("3.0.0"):
             raise RuntimeError(
                 "'CategoricalRewardEstimator' was removed in IAI v3")
 
@@ -679,7 +701,7 @@ class CategoricalRewardEstimator(CategoricalRewardEstimationLearner):
         super().__init__(jl_obj)
 
 
-class RewardEstimator(CategoricalRewardEstimator, RewardEstimationLearner):
+class RewardEstimator(CategoricalRewardEstimator):
     """Learner for reward estimation with categorical treatments.
 
     This class was deprecated and renamed to CategoricalRewardEstimator in
@@ -691,7 +713,7 @@ class RewardEstimator(CategoricalRewardEstimator, RewardEstimationLearner):
     Requires IAI version 2.2 or lower.
     """
     def __init__(self, *args, **kwargs):
-        if not _iai_version_less_than("2.3.0"):
+        if not _iai_version_less_than("3.0.0"):
             raise RuntimeError("'RewardEstimator' was removed in IAI v3")
 
         _warnings.warn(
@@ -725,7 +747,7 @@ class NumericRewardEstimator(NumericRewardEstimationLearner):
     Requires IAI version 2.1 or 2.2.
     """
     def __init__(self, *args, outcome_estimator=None, **kwargs):
-        if not _iai_version_less_than("2.3.0"):
+        if not _iai_version_less_than("3.0.0"):
             raise RuntimeError(
                 "'NumericRewardEstimator' was removed in IAI v3")
 
